==> 1.1.0.tar.gz: lxqt-config-1.1.0/liblxqt-config-cursor/translations/lxqt-config-cursor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Wygląd kursora</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="46"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Wybierz styl kursora (najedź kursorem na podgląd, aby przetestować). &lt;b&gt;Wymagane jest ponowne uruchomienie sesji&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="23"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Zainstaluj Nowy Motyw…</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>Sesja LXQt musi zostać zrestartowana, aby zmiana była widoczna.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="91"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Usuń Motyw</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>XCurTheme error</source>
        <translation>Błąd XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="232"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Nie możesz usunąć aktywnego motywu!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>Nie znaleziono żadnego motywu kursora. Zostanie użyty domyślny motyw kursora X11. LXQt wyszukiwało w następujących katalogach:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Pokaż…</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
</TS>

==> 2.1.0.tar.gz: lxqt-config-2.1.0/liblxqt-config-cursor/translations/lxqt-config-cursor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Wygląd kursora</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Wybierz styl kursora (najedź kursorem na podgląd, aby przetestować). &lt;b&gt;Wymagane jest ponowne uruchomienie sesji&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="104"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Zainstaluj nowy motyw…</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>Sesja LXQt musi zostać zrestartowana, aby zmiana była widoczna.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Usuń motyw</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="65"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="229"/>
        <source>XCurTheme error</source>
        <translation>Błąd XCurTheme</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="230"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Nie możesz usunąć aktywnego motywu!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>Nie znaleziono żadnego motywu kursora. Zostanie użyty domyślny motyw kursora X11. LXQt wyszukiwało w następujących katalogach:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Pokaż…</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="63"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
</context>
</TS>
